% This is a function to perform batch classification of a set of feature 
% vectors given a binary decision tree. 
%
% Usage: y = batchClassifyWithDT(x)
%
% Inputs: 
%
%   x - a S by D matrix, where S is the number of samples and D is the
%   length of a feature vector.   x(s,:) gives the feature vector for 
%   sample s. 
%
%   dT - a decision tree.  See function trainDT for definition of this
%   structure. 
%
% Outputs: 
%
%   y - an S by 1 array.  y(s) gives the estimated label for sample s. 
%
function y = batchClassifyWithDT(x, dT)

nSmps = size(x,1); 
y = nan(nSmps,1); 
for s = 1:nSmps
    y(s) = classifyWithDT(x(s,:), dT);
end