% This is a function to classify a feature vector given a binary
% decision tree. 
%
% Usage: y = classifyWithDT(x)
%
% Inputs: 
%
%   x - a 1 by D array giving the feature vector a single sample
%
%   dT - a decision tree.  See function trainDT for definition of this
%   structure. 
%
% Outputs: 
%
%   y - The estimated class label for the sample.
%
function y = classifyWithDT(x, dT)

assert(size(x,1) == 1, 'classifyWithDT only works for one sample.  For multiple samples call batchClassifyWithDt.'); 

nSmps = size(x,1); 

if dT.isLeaf
    y = repmat(dT.label, [nSmps, 1]);
else
    if x(dT.attr) <= dT.thresh
        y = classifyWithDT(x, dT.child1);
    else
        y = classifyWithDT(x, dT.child2);
    end 
end