% Given a set of training data, this is a function to select the single
% best attribute to perform a binary split with, as measured by information
% gain, and the particular threshold to perform that split at. 
%
% Usage: [attr, thresh] = computeOptimalSplit(x, y)
%
% Inputs: 
%
%   x - a S by D matrix, where S is the number of samples and D is the
%   length of a feature vector.   x(s,:) gives the feature vector for 
%   sample s. 
%
%   y - an S by 1 array.  y(s) gives the label for sample s. 
%
% Outputs: 
%
%   attr - this is the index of the best attribute to perform a split at.
%   
%   thresh - this is the threshold at which the split should be performed.
%            
%   Thus, the splitting rule for sample s will be: 
%
%       split into class 1,      if x(s,attr) <= thresh, 
%       split into class 2,      otherwise
%       
% Example: 
%
%  If: 
%
%       x = [1 2 3 4 5 6 7 8 9; 2 2 2 2 2 2 2 2 2]'
% 
%       y = [0 0 0 0 0 1 1 1 1]'
%
%
%   and we call: 
%
%      [attr, thresh] = computeOptimalSplit(x, y)
%
%   then: 
%
%       attr = 1
%       
%       thresh = 5.5
%
function [attr, thresh] = computeOptimalSplit(x, y)

% Please provide the code for this function 
